# compression_opts

```
usage: compression_opts [-h] path

Get dataset compression_opts

positional arguments:
  path        Path to dataset

optional arguments:
  -h, --help  show this help message and exit
```
